[![Build Status](https://github.com/OCHA-DAP/hdx-scraper-geonode/actions/workflows/run-python-tests.yaml/badge.svg)](https://github.com/OCHA-DAP/hdx-scraper-geonode/actions/workflows/run-python-tests.yaml)
[![Coverage Status](https://coveralls.io/repos/github/OCHA-DAP/hdx-scraper-geonode/badge.svg?branch=main&ts=1)](https://coveralls.io/github/OCHA-DAP/hdx-scraper-geonode?branch=main)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://pycqa.github.io/isort/)
[![Downloads](https://img.shields.io/pypi/dm/hdx-scraper-geonode.svg)](https://pypistats.org/packages/hdx-scraper-geonode)

The HDX Scraper Geonode Library enables easy building of scrapers for extracting data 
from [GeoNode](https://geonode.org/) servers. GeoNode is a web-based application and 
platform for developing geospatial information systems (GIS) and for deploying spatial 
data infrastructures (SDI). 

For more information, please read the 
[documentation](https://hdx-scraper-geonode.readthedocs.io/en/latest/). 

This library is part of the [Humanitarian Data Exchange](https://data.humdata.org/) 
(HDX) project. If you have humanitarian related data, please upload your datasets to 
HDX.
